from django.urls import re_path, path
from rest_framework.routers import DefaultRouter
from gregui.api.views.identity import IdentityViewSet

from gregui.api.views.invitation import (
    CheckInvitationView,
    ResendInvitationView,
    InvitationView,
    InvitedGuestView,
)
from gregui.api.views.person import PersonSearchView, PersonView
from gregui.api.views.role import RoleInfoViewSet
from gregui.api.views.roletypes import RoleTypeViewSet
from gregui.api.views.unit import UnitsViewSet

router = DefaultRouter(trailing_slash=False)
router.register(r"role", RoleInfoViewSet, basename="role")
router.register(r"identity", IdentityViewSet, basename="identity")

urlpatterns = router.urls
urlpatterns += [
    re_path(r"roletypes/$", RoleTypeViewSet.as_view(), name="role-types"),
    re_path(r"units/$", UnitsViewSet.as_view(), name="units"),
    path("invited/", InvitedGuestView.as_view(), name="invited-info"),
    path("invitecheck/", CheckInvitationView.as_view(), name="invite-verify"),
    path(
        "invite/<int:person_id>/resend",
        ResendInvitationView.as_view(),
        name="invite-resend",
    ),
    path("invite/", InvitationView.as_view(), name="invitation"),
    path("person/<int:id>", PersonView.as_view(), name="person-get"),
    path(
        "person/search/<searchstring>", PersonSearchView.as_view(), name="person-search"
    ),
]
